@@ -280,10 +280,15 @@ class MMSSender:
 			print "connecting without proxy"
 			mmsc = mmsc.replace("http://", "")
 			mmsc = mmsc.rstrip('/')
-			conn = httplib.HTTPConnection(mmsc)
-			conn.request('POST', '/', mms, headers)
+			mmsc = mmsc.partition('/')
+			mmschost = mmsc[0]
+			path = "/" + str(mmsc[2])
+			print "mmschost:", mmschost, "path:", path, "pathlen:", len(path)
+			conn = httplib.HTTPConnection(mmschost)
+			conn.request('POST', path , mms, headers)
 		else:
 			print "connecting via proxy " + proxyurl + ":" + str(proxyport)
+			print "mmschost:", mmsc
 			conn = httplib.HTTPConnection(proxyurl + ":" + str(proxyport))
 			conn.request('POST', mmsc, mms, headers)
 			
